package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.EGovernmentNetwork;

/**
 * 电子政务网Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IEGovernmentNetworkService 
{
    /**
     * 查询电子政务网
     * 
     * @param id 电子政务网主键
     * @return 电子政务网
     */
    public EGovernmentNetwork selectEGovernmentNetworkById(Integer id);

    /**
     * 查询电子政务网列表
     * 
     * @param eGovernmentNetwork 电子政务网
     * @return 电子政务网集合
     */
    public List<EGovernmentNetwork> selectEGovernmentNetworkList(EGovernmentNetwork eGovernmentNetwork);

    /**
     * 新增电子政务网
     * 
     * @param eGovernmentNetwork 电子政务网
     * @return 结果
     */
    public int insertEGovernmentNetwork(EGovernmentNetwork eGovernmentNetwork);

    /**
     * 修改电子政务网
     * 
     * @param eGovernmentNetwork 电子政务网
     * @return 结果
     */
    public int updateEGovernmentNetwork(EGovernmentNetwork eGovernmentNetwork);

    /**
     * 批量删除电子政务网
     * 
     * @param ids 需要删除的电子政务网主键集合
     * @return 结果
     */
    public int deleteEGovernmentNetworkByIds(Integer[] ids);

    /**
     * 删除电子政务网信息
     * 
     * @param id 电子政务网主键
     * @return 结果
     */
    public int deleteEGovernmentNetworkById(Integer id);
}
